# Howard, FUN documents for Marion, The Documents Factory

Howard is a collection of document issuers for
[Marion](https://openfun.github.io/marion).

## Contributing

This project is intended to be community-driven, so please, do not hesitate to
get in touch if you have any questions related to our implementation or design
decisions.

We try to raise our code quality standards and expect contributors to follow
the recommendations from our
[handbook](https://openfun.gitbooks.io/handbook/content).

## License

This work is released under the MIT License (see [LICENSE](./LICENSE))
